@@ -1,8 +1,9 @@
 import sys
-from .kerasmodel import KerasModel,train_model
+from .kerasmodel import KerasModel
 from .summary import summary
+from .kerasmodel import colorful
 try:
     from .lightmodel import LightModel 
 except Exception:
     print("torchkeras.LightModel can't be used!",file = sys.stderr)
-__version__='3.3.1'
+__version__='3.3.2'
